@@ -14,10 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
  
 #include "config.h"
@@ -32,16 +30,16 @@
 #include "seahorse-pgp-key.h"
 #include "seahorse-pgp-subkey.h"
 #include "seahorse-pgp-uid.h"
-#include "seahorse-servers.h"
 
-#include "seahorse-object-list.h"
-#include "seahorse-progress.h"
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-object-list.h"
+#include "libseahorse/seahorse-progress.h"
+#include "libseahorse/seahorse-servers.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <libsoup/soup.h>
 
 #define DEBUG_FLAG SEAHORSE_DEBUG_HKP
-#include "seahorse-debug.h"
+#include "libseahorse/seahorse-debug.h"
 
 /**
  * SECTION: seahorse-hkp-source
