@@ -14,24 +14,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
-#include <config.h>
+#include "config.h"
+
+#include "seahorse-keyserver-search.h"
 
 #include "seahorse-discovery.h"
-#include "seahorse-keyserver-search.h"
 #include "seahorse-keyserver-results.h"
 #include "seahorse-pgp-backend.h"
 
-#include "seahorse-servers.h"
-#include "seahorse-util.h"
-#include "seahorse-widget.h"
-
-#include "seahorse-keyserver-results.h"
+#include "libseahorse/seahorse-servers.h"
+#include "libseahorse/seahorse-util.h"
+#include "libseahorse/seahorse-widget.h"
 
 /**
  * SECTION:seahorse-keyserver-search
