@@ -16,27 +16,14 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 /* TODO: Make sure to free when getting text from seahorse_pgp_key_* */
 
 #include "config.h"
 
-#include <string.h>
-  
-#include <glib/gi18n.h>
-
-#include "seahorse-bind.h"
-#include "seahorse-common.h"
-#include "seahorse-object.h"
-#include "seahorse-object-model.h"
-#include "seahorse-object-widget.h"
-#include "seahorse-util.h"
-
 #include "seahorse-gpgme-dialogs.h"
 #include "seahorse-gpgme-exporter.h"
 #include "seahorse-gpgme-key.h"
@@ -49,9 +36,20 @@
 #include "seahorse-pgp-signature.h"
 #include "seahorse-pgp-subkey.h"
 
-#define DEBUG_FLAG SEAHORSE_DEBUG_KEYS
-#include "seahorse-debug.h"
+#include "seahorse-common.h"
 
+#include "libseahorse/seahorse-bind.h"
+#include "libseahorse/seahorse-object.h"
+#include "libseahorse/seahorse-object-model.h"
+#include "libseahorse/seahorse-object-widget.h"
+#include "libseahorse/seahorse-util.h"
+
+#define DEBUG_FLAG SEAHORSE_DEBUG_KEYS
+#include "libseahorse/seahorse-debug.h"
+
+#include <glib/gi18n.h>
+
+#include <string.h>
 #include <time.h>
 
 #define NOTEBOOK "notebook"
