@@ -14,10 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -25,9 +23,10 @@
 #include "seahorse-ssh-operation.h"
 
 #include "seahorse-common.h"
+
 #define DEBUG_FLAG SEAHORSE_DEBUG_OPERATION
-#include "seahorse-debug.h"
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-debug.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <sys/wait.h>
 #include <signal.h>
